#include "Arduino.h"
#include "theSecrets.h"
#include "WiFi.h"
#include "lwip_hooks.h"

int lwip_hook_ip4_input(struct pbuf *pbuf, struct netif *input_netif)
{
    const struct ip_hdr *iphdr;
    char ip_address[IP_HLEN];

    iphdr = (struct ip_hdr *)pbuf->payload;
    sprintf(ip_address, "%d.%d.%d.%d", ip4_addr1_16_val(iphdr->src), ip4_addr2_16_val(iphdr->src), ip4_addr3_16_val(iphdr->src), ip4_addr4_16_val(iphdr->src));
    Serial.print((u16_t)IPH_PROTO(iphdr));
    Serial.print(": ");
    Serial.println(ip_address);
    return 0;
}

void handle_wifi_events(WiFiEvent_t event, WiFiEventInfo_t info)
{
    Serial.print("[WiFi] ");
    switch (event)
    {
    case ARDUINO_EVENT_WIFI_STA_START:
        Serial.println("connecting...");
        break;
    case ARDUINO_EVENT_WIFI_STA_CONNECTED:
        Serial.println("connected");
        break;
    case ARDUINO_EVENT_WIFI_STA_DISCONNECTED:
        Serial.println("disconnected");
        break;
    case ARDUINO_EVENT_WIFI_STA_GOT_IP:
        Serial.print("IP: ");
        Serial.println(WiFi.localIP().toString().c_str());
        break;
    default:
        Serial.print("other event: ");
        Serial.println(event);
    }
}

void setup_wifi()
{
    WiFi.mode(WIFI_STA);
    WiFi.onEvent(handle_wifi_events, ARDUINO_EVENT_MAX);
    WiFi.begin(ssid, psk);

    // fix for https://github.com/espressif/arduino-esp32/issues/4732
    WiFi.config(((u32_t)0x0UL), ((u32_t)0x0UL), ((u32_t)0x0UL));
}

void setup()
{
    Serial.begin(115200);
    setup_wifi();
}

void loop()
{
    sleep(60);
}